package edu.uoc.sm.contactdb.dao;

import edu.uoc.sm.contactdb.data.CircleData;
import edu.uoc.sm.contactdb.data.ContactData;
import edu.uoc.sm.contactdb.data.EmailAccountData;
import edu.uoc.sm.contactdb.data.PhoneData;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.List;

/**
 * Data Access Object for ContactData
 * 
 * @author Salvador Morla
 * @version 1.0
 * 
 */
public class ContactDAO {
    
    private int nextId;
    private List<ContactData> list;
    private static ContactDAO singleton;
    
    
    public static ContactDAO getDAO() {
        if(singleton == null) { singleton = new ContactDAO(); }
        return singleton;
    }
    
    private ContactDAO() {
        this.nextId = 1;
        this.list = new ArrayList<ContactData>();
        init();
    }
    
    public List<ContactData> findAll() {
        return this.list;
    }
    
    public void insert(ContactData m) {
        m.setId(nextId++);
        list.add(m);
    }
    
    public void update(ContactData m) {
        for(int i=0;i<list.size();i++) {
            ContactData c = list.get(i);
            if(c.getId().intValue() == m.getId().intValue()) {                
                
                c.setBirthDate(m.getBirthDate());
                c.setFirstName(m.getFirstName());
                c.setFullAdress(m.getFullAdress());
                c.setMoneyDebt(m.getMoneyDebt());
                c.setNotes(m.getNotes());
                c.setOwesMeMoney(m.getOwesMeMoney());
                c.setSurname(m.getSurname());
                c.setWebSite(m.getWebSite());
                break;
            }
        }
    }
    
    public ContactData find(int id) {
        ContactData c = null;
        for(int i=0;i<list.size();i++) {
            if(list.get(i).getId() == id) {
                c = list.get(i);
                break;
            }
        }
        return c;
    }
    
    public void delete(int id) {
        for(int i=0;i<list.size();i++) {
            if(list.get(i).getId() == id) {
                list.remove(i);
                break;
            }
        }    
    }
    
    
    public void addCircle(Integer contactId, Integer circleId) throws Exception {
        CircleDAO circleDao = CircleDAO.getDAO();        
        ContactData c  = find(contactId);
        CircleData cir = circleDao.find(circleId);        
        if (cir == null) {
            throw new Exception("Circle not exist!");
        }
        for (CircleData o: c.getCircleList()) {
            if (o.getId().intValue() == circleId.intValue()) {
                throw new Exception("Circle already associated to contact!");
            }
        }
        c.getCircleList().add(cir);
    }
    
    
    public void removeCircle(Integer contactId, Integer circleId) {
        ContactData c  = find(contactId);
        for (int i=0; i<c.getCircleList().size();i++) {
            if (c.getCircleList().get(i).getId().intValue() == circleId.intValue()) {
                c.getCircleList().remove(i);
                break;
            }
        }
    }

    private void init() {
        SimpleDateFormat sdf = new SimpleDateFormat("dd/MM/yyyy");
        
        try {
            ContactData c;
            c = new ContactData();
            c.setId(nextId++);
            c.setFirstName("Peter");
            c.setSurname("Sherman");
            c.setBirthDate(sdf.parse("12/08/1977"));   
            c.setFullAdress("42, Wallaby Way, Sydney");
            c.setOwesMeMoney(Boolean.TRUE);
            c.setMoneyDebt(150.50);
            c.setWebSite("www.nowhere.com");
            c.setNotes("Test purpose contact");
            
            PhoneData p;
            p = new PhoneData();
            p.setContactId(c.getId());
            p.setPhoneNumber("666666666");
            p.setPhoneName("Cell");
            c.getPhonesList().add(p);
            p = new PhoneData();
            p.setContactId(c.getId());
            p.setPhoneNumber("916555444");
            p.setPhoneName("Work");
            
            EmailAccountData e;
            e = new EmailAccountData();
            e.setContactId(c.getId());
            e.setEmailAccount("psherman@hotmail.com");
            e.setEmailAccountName("Personal");
            c.getEmailAccountList().add(e);
            
            CircleData cr = CircleDAO.getDAO().findAll().get(0);
            c.getCircleList().add(cr);
            
            this.list.add(c);
        }
        catch(ParseException pe) {            
        }
        
    }

}