package edu.uoc.sm.contactdb.data;

import edu.uoc.pfc.sm.annotation.FieldValidation;
import edu.uoc.pfc.sm.data.Data;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * Represents a ContactData in the system.
 * 
 * @author Salvador Morla
 * @version 1.0
 */
public class ContactData extends Data {
    
    // Class properties
    
    // Id
    @FieldValidation (type="PositiveInteger", notNull=true)
    private Integer id;
    
    // ContactData name
    @FieldValidation (type="TextString", notNull=true, maxLength=25)
    private String firstName;
    
    // ContactData surname
    @FieldValidation (type="TextString", maxLength=25)
    private String surname;
    
    // Birthdate
    @FieldValidation (type="Date")
    private Date birthDate;
    
    // Full address
    @FieldValidation (type="TextString", maxLength=200)
    private String fullAdress;
    
    // WebSite
    @FieldValidation (type="TextString", maxLength=200)
    private String webSite;
    
    // ContactData notes Notes
    @FieldValidation (type="TextString", maxLength=500)
    private String notes;
    
    // Owes me money
    private Boolean owesMeMoney;
    
    // MoneyDebt
    @FieldValidation (type="PositiveNumber", maxValue=999999)
    private Double moneyDebt;
    
    // PhoneData number list
    private List<PhoneData> phonesList;
    
    // Email account list
    private List<EmailAccountData> emailAccountList;
    
    // Circle list
    private List<CircleData> circleList;
    
    /**
     * @return the id
     */
    public Integer getId() {
        return id;
    }

    /**
     * @param id the id to set
     */
    public void setId(Integer id) {
        this.id = id;
    }

    /**
     * @return the firstName
     */
    public String getFirstName() {
        return firstName!=null?firstName:"";
    }

    /**
     * @param firstName the firstName to set
     */
    public void setFirstName(String firstName) {
        this.firstName = firstName;
    }

    /**
     * @return the surname
     */
    public String getSurname() {
        return surname!=null?surname:"";
    }

    /**
     * @param surname the surname to set
     */
    public void setSurname(String surname) {
        this.surname = surname;
    }

    /**
     * @return the birthDate
     */
    public Date getBirthDate() {
        return birthDate;
    }

    /**
     * @param birthDate the birthDate to set
     */
    public void setBirthDate(Date birthDate) {
        this.birthDate = birthDate;
    }

    /**
     * @return the fullAdress
     */
    public String getFullAdress() {
        return fullAdress!=null?fullAdress:"";
    }

    /**
     * @param fullAdress the fullAdress to set
     */
    public void setFullAdress(String fullAdress) {
        this.fullAdress = fullAdress;
    }

    /**
     * @return the webSite
     */
    public String getWebSite() {
        return webSite!=null?webSite:"";
    }

    /**
     * @param webSite the webSite to set
     */
    public void setWebSite(String webSite) {
        this.webSite = webSite;
    }

    /**
     * @return the notes
     */
    public String getNotes() {
        return notes!=null?notes:"";
    }

    /**
     * @param notes the notes to set
     */
    public void setNotes(String notes) {
        this.notes = notes;
    }

    /**
     * @return the phonesList
     */
    public List<PhoneData> getPhonesList() {
        if (phonesList == null) {
            phonesList = new ArrayList<PhoneData>();
        }
        return phonesList;
    }

    /**
     * @param phonesList the phonesList to set
     */
    public void setPhonesList(List<PhoneData> phonesList) {
        this.phonesList = phonesList;
    }

    /**
     * @return the emailAccountList
     */
    public List<EmailAccountData> getEmailAccountList() {
        if (emailAccountList == null) {
            emailAccountList = new ArrayList<EmailAccountData>();
        }
        return emailAccountList;
    }

    /**
     * @param emailAccountList the emailAccountList to set
     */
    public void setEmailAccountList(List<EmailAccountData> emailAccountList) {
        this.emailAccountList = emailAccountList;
    }

    /**
     * @return the owesMeMoney
     */
    public Boolean getOwesMeMoney() {
        return owesMeMoney;
    }

    /**
     * @param owesMeMoney the owesMeMoney to set
     */
    public void setOwesMeMoney(Boolean owesMeMoney) {
        this.owesMeMoney = owesMeMoney;
    }

    /**
     * @return the moneyDebt
     */
    public Double getMoneyDebt() {
        return moneyDebt;
    }

    /**
     * @param moneyDebt the moneyDebt to set
     */
    public void setMoneyDebt(Double moneyDebt) {
        this.moneyDebt = moneyDebt;
    }
    
    
    
    /**
     * @return the circleList
     */
    public List<CircleData> getCircleList() {
        if (circleList == null) {
            circleList = new ArrayList<CircleData>();
        }
        return circleList;
    }

    /**
     * @param circleList the circleList to set
     */
    public void setCircleList(List<CircleData> circleList) {
        this.circleList = circleList;
    }
}
