package edu.uoc.pfc.sm.annotation;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Indica sobre una propietat de una classe que aquesta ha de ser validada
 * pel controlador.
 * 
 * @author Salvador Morla
 * @version 1.0.
 */
@Target(ElementType.FIELD)
@Retention(RetentionPolicy.RUNTIME)
public @interface FieldValidation {
    
    /* Defineix el tipus de validacio a efectuar (la classe) */
    String type();     
    
    /* Patró basat en una expressio reguar a emprar per la validació
       si no s'especifica res, se pren la defaultPattern */
    String pattern() default "";  
    
    /* Llargaria màxima per cadenes de text */
    int maxLength()  default 0;
    /* Llargaria minima per cadenes de text */
    int minLength()  default 0;
    /* Valor numeric maxim */
    int minValue()   default 0;
    /* Valor numeric minim */
    int maxValue()   default 0;
    
    /* Indica obligatorietat quan s'estableix a true */
    boolean notNull() default false;
}
