package edu.uoc.pfc.sm.error;

import edu.uoc.pfc.sm.annotation.ErrorDestination;
import java.io.IOException;
import java.net.URLEncoder;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * Gestiona els errors que se produeixen al controlador
 * 
 * @author Salvador Morlá
 * @version 1.0
 */
public class SMControllerErrorHandler {
    
    /**
     * Gestiona les excepcions que se produeixen durant el processament de les 
     * peticions per part del controlador. Endemés, s'encarrega de redirigir
     * la navegació a la vista d'error anotada a l'action des de on se produeix
     * l'error.
     * 
     * @param request el request
     * @param response el response
     * @param destination L'anotació ErrorDestination de l'action o se produeix
     * l'error
     * @param actionError la classe amb l'error produit.
     * @throws ServletException 
     */
    public void handleError(HttpServletRequest request, HttpServletResponse response, ErrorDestination destination, SMControllerError smControllerError) throws ServletException {
        if (destination == null) {
            throw new ServletException(smControllerError);
        }
        if (destination.redirect()) {
            try {
                // Se pasa el texte de l'error com a parametre a la vista de destí.
                response.sendRedirect(request.getContextPath() + (destination.value().startsWith("/") ? destination.value() : ("/" + destination.value())) + "?SMControllerError=" + URLEncoder.encode(smControllerError.getMessage()));
            } catch (IOException ex) {
                throw new ServletException("Error redireccionant la navegacio a la pagina d'error " + destination.value() + "(" + ex.getMessage() + ")", smControllerError);
            }
        } else {
            // Se pasa el texte de l'error com a atribut del request.
            request.setAttribute("SMControllerError", smControllerError);
            try {
                request.getRequestDispatcher(destination.value().startsWith("/") ? destination.value() : ("/" + destination.value())).forward(request, response);
            } catch (IOException ex) {
                throw new ServletException("Error processant la pagina d'error " + destination.value() + "(" + ex.getMessage() + ")", smControllerError);
            }
        }
    }
    
}
