package edu.uoc.pfc.sm.validation;

import edu.uoc.pfc.sm.util.ValidateUtils;
import java.text.ParsePosition;
import java.text.SimpleDateFormat;

/**
 * Validador de SMController per camps de data i hora.
 * 
 * @author Salvador Morla
 * @version 1.0
 */
public class DateTime extends SMControllerValidationType implements SMControllerDataFieldValidator {
    
    /* 
     * Patró per defecte. En aquest cas el patro ha de ser un format per data
     * valid.
     */
    public DateTime() {}
    
    private String defaultPattern = "dd/MM/yyyy hh:mm"; 
    
    public SMControllerFieldError validate() {
        
        SMControllerFieldError error = null;
        
        if (super.getPattern() == null) {
            super.setPattern(defaultPattern);
        }
        
        String s = super.getValue();
        
        s = ValidateUtils.notNullValue(s);        
        s = ValidateUtils.deleteBlankSpaces(s);
        
        try {
            SimpleDateFormat formatter = new SimpleDateFormat(super.getPattern());
            java.util.Date d = formatter.parse(s, new ParsePosition(0));
            new java.sql.Timestamp(d.getTime());
        }
        catch (Exception ex) {
            error = new SMControllerFieldError();
            error.setFieldValue(super.getValue());
            error.setErrorMessage("El format de la data i hora no és correcte. Ha de seguir el patró "+super.getPattern());
        }
        return error;
    }
    
}
