package edu.uoc.pfc.sm.validation;

import edu.uoc.pfc.sm.util.Constants;
import edu.uoc.pfc.sm.util.ValidateUtils;
import java.util.regex.Pattern;

/**
 * Validador de SMController per camps de data.
 * 
 * @author Salvador Morla
 * @version 1.0
 */
public class EmailAddress extends SMControllerValidationType implements SMControllerDataFieldValidator {
    
    public EmailAddress() {};
    
    private String defaultPattern = "\\b[\\w.%-]+@[-.\\w]+\\.[A-Za-z]{2,4}\\b";
    
    @Override
    public SMControllerFieldError validate() {
        
        SMControllerFieldError error = null;
        String errorMessage = Constants.EMPTY_STRING;
        
        String s = super.getValue();
        s = ValidateUtils.notNullValue(s);        
        s = ValidateUtils.deleteBlankSpaces(s);
      
        if (super.getPattern().equals("")) {
            super.setPattern(defaultPattern);
        }
        try {            
            if (super.getNotNull().booleanValue() && s.length() == 0) {
                errorMessage = "El camp es obligatori";
            }
            else {
                if (!Pattern.matches(super.getPattern(), s)) {
                    errorMessage = "No s'ha especificat un valor correcte.";
                }
                else {
                   
                    if (super.getMaxValue() > 0 && s.length() > super.getMaxLength()) {
                        errorMessage = "El valor supera la llargaria màxima permesa ("+super.getMaxLength()+").";
                    }
                    if (super.getMinValue() > 0 && s.length() < super.getMinLength()) {
                        errorMessage = "El valor no arriba a la llargaria mínima requerida ("+super.getMinLength()+").";
                    }                                       
                }
            }
            if (errorMessage.length() > 0) {
                error = new SMControllerFieldError();
                error.setFieldValue(super.getValue());
                error.setErrorMessage(errorMessage);
            }
        }
        catch (Exception ex) {
            error = new SMControllerFieldError();
            error.setFieldValue(super.getValue());
            error.setErrorMessage("No s'ha especificat un valor correcte.");
        }
        return error;
    }
    
}
