package edu.uoc.pfc.sm.validation;

import edu.uoc.pfc.sm.util.Constants;
import edu.uoc.pfc.sm.util.ValidateUtils;
import java.util.regex.Pattern;

/**
 * Validador de SMController per camps de data.
 * 
 * @author Salvador Morla
 * @version 1.0
 */
public class PositiveNumber extends SMControllerValidationType implements SMControllerDataFieldValidator {
    
    public PositiveNumber() {};
    
    private String defaultPattern = "[\\+-]?\\d*(\\.\\d+)?";
    
    @Override
    public SMControllerFieldError validate() {
        
        SMControllerFieldError error = null;
        String errorMessage = Constants.EMPTY_STRING;
        
        String s = super.getValue();
        s = ValidateUtils.notNullValue(s);        
        s = ValidateUtils.deleteBlankSpaces(s);
      
        
        try {            
            if (super.getNotNull() && s.length() == 0) {
                errorMessage = "El camp es obligatori";
            }
            else {
                if (s.length() > 0) {
                    if (!Pattern.matches(defaultPattern, s)) {
                        errorMessage = "No s'ha especificat un valor numèric correcte.";
                    }
                    else {
                        Double d = Double.parseDouble(s);

                        if (d < 0) {
                            errorMessage = "El valor ha de ser un nombre positiu";
                        }                        
                        if (super.getMaxValue() > 0 && d > super.getMaxValue()) {
                            errorMessage = "El valor supera el màxim permés (max. "+super.getMaxValue()+")";
                        }
                        if (super.getMinValue() > 0 && d < super.getMinValue()) {
                            errorMessage = "El valor no arriba al mínim establert (min. "+super.getMinValue()+")";
                        }                                
                    }
                }
            }
            if (errorMessage.length() > 0) {
                error = new SMControllerFieldError();
                error.setFieldValue(super.getValue());
                error.setErrorMessage(errorMessage);
            }
          
        }
        catch (Exception ex) {
            error = new SMControllerFieldError();
            error.setFieldValue(super.getValue());
            error.setErrorMessage("No s'ha especificat un valor numèric correcte.");
        }
        return error;
    }
    
}
