package edu.uoc.pfc.sm.validation;

import edu.uoc.pfc.sm.util.ValidateUtils;
import java.text.ParsePosition;
import java.text.SimpleDateFormat;

/**
 * Validador de SMController per camps de data.
 * 
 * @author Salvador Morla
 * @version 1.0
 */
public class Time extends SMControllerValidationType implements SMControllerDataFieldValidator {
    
    /* 
     * Patró per defecte. En aquest cas el patro ha de ser un format per data
     * valid.
     */
    private String defaultPattern = "hh:mm"; 
    
    public Time() {};
    
    @Override
    public SMControllerFieldError validate() {
        
        SMControllerFieldError error = null;
        
        String s = super.getValue();
        s = ValidateUtils.notNullValue(s);        
        s = ValidateUtils.deleteBlankSpaces(s);
        
        if (super.getPattern() == null) {
            super.setPattern(defaultPattern);
        }
        
        try {            
            if (super.getNotNull() && s.length() == 0) {
                error = new SMControllerFieldError();
                error.setFieldValue(super.getValue());
                error.setErrorMessage("El camp es obligatori");
            }
            else {
                if (s.length() > 0) {
                    SimpleDateFormat sdf = new SimpleDateFormat(super.getPattern());
                    java.util.Date d = sdf.parse(s, new ParsePosition(0));
                    
                    if (d == null) {
                       error = new SMControllerFieldError();
                       error.setFieldValue(super.getValue());
                       error.setErrorMessage("El format de la hora no és correcte. Ha de seguir el patró "+super.getPattern());
                    }
                }
            }
        }
        catch (Exception ex) {
            error = new SMControllerFieldError();
            error.setFieldValue(super.getValue());
            error.setErrorMessage("El format de la data no és correcte. Ha de seguir el patró "+super.getPattern());
        }
        return error;
    }
    
}
